require(car)
require(lsmeans)
require(lme4)
require(lmerTest)


##Test for relationship between field-measured traits and altitude
## dataset = Field_Phenotypes

shapiro.test(UVP)
shapiro.test(UVA)
shapiro.test(PA)
shapiro.test(ANGLE)

year<-as.factor(YEAR)


mod.uvp<-lm(UVP~MASL+year)
Anova(mod.uvp, type=3)


mod.uva<-lm(UVA~MASL+year)
Anova(mod.uva, type=3)


mod.angle<-lm(ANGLE~MASL*year)
Anova(mod.angle, type=3)

mod.pa<-lm(PA~MASL*year)
Anova(mod.pa, type=3)

## obtain linear model parameters for each year separately

y1<-field[which(field$year=='2012')]
y2<-field[which(field$year=='2020')]

lm.uvp.y1<-lm(y1$UVP~y1$MASL)
lm.uvp.y2<-lm(y2$UVP~y2$MASL)

lm.uva.y1<-lm(y1$UVA~y1$MASL)
lm.uva.y2<-lm(y2$UVA~y2$MASL)

lm.ang.y1<-lm(y1$ANGLE~y1$MASL)
lm.ang.y2<-lm(y2$ANGLE~y2$MASL)

lm.pa.y1<-lm(y1$PA~y1$MASL)
lm.pa.y2<-lm(y2$PA~y2$MASL)


## Testing for Plasticity, and Differential Plasticity between low and high elevation populations
## Dataset = Greenhouse_Plasticity_Data

BLOCK<-as.factor(Block)
day<-as.factor(Day)
geno<-as.factor(Geno)


mod.UVP<-lmer(UVP~Elev*TRT+Elev*day+TRT*day+TRT*DOFF+Elev*DOFF+LfHt+Pop %in% Elev+(1|Pop:geno)+(1|BLOCK))
mod.UVA<-lmer(UVA~Elev*TRT+Elev*day+TRT*day+TRT*DOFF+Elev*DOFF+LfHt+Pop %in% Elev+PA+(1|Pop:geno)+(1|BLOCK))
mod.angle<-lmer(Angle~Elev*TRT+Elev*day+TRT*day+TRT*DOFF+Elev*DOFF+LfHt+Pop %in% Elev+PA+(1|Pop:geno)+(1|BLOCK))
mod.pa<-lmer(PA~Elev*TRT+Elev*day+TRT*day+TRT*DOFF+Elev*DOFF+LfHt+Pop %in% Elev+(1|Pop:geno)+(1|BLOCK))
mod.apex<-lmer(UVRefApex~Elev*TRT+Elev*day+TRT*day+TRT*DOFF+Elev*DOFF+LfHt+Pop %in% Elev+PA+(1|Pop:geno)+(1|BLOCK))

mod.base<-glmer(UVRefBase~Elev*TRT+Elev*day+TRT*day+TRT*DOFF+Elev*DOFF+LfHt+Pop %in% Elev+PA+(1|Pop:geno)+(1|BLOCK), family= Gamma)



## F-test, Type III SS, for each model, and likelihood ratio test for random terms

anova(mod.UVP)
ranova(mod.UVP)

#run above for each model


# Post-hoc tests of differences between traits by elevation within treatment, and by treatment within elevation
emmeans(mod.UVP, list(pairwise~TRT|Elev))
emmeans(mod.UVP, list(pairwise~Elev|TRT))

emmeans(mod.UVA, list(pairwise~TRT|Elev))
emmeans(mod.UVA, list(pairwise~Elev|TRT))

emmeans(mod.angle, list(pairwise~TRT|Elev))
emmeans(mod.angle, list(pairwise~Elev|TRT))

emmeans(mod.pa, list(pairwise~TRT|Elev))
emmeans(mod.pa, list(pairwise~Elev|TRT))

emmeans(mod.apex, list(pairwise~TRT|Elev))
emmeans(mod.apex, list(pairwise~Elev|TRT))

emmeans(mod.base, list(pairwise~Elev|TRT))
emmeans(mod.base, list(pairwise~Elev|TRT))



## measure selection on pigmentation via pollen viability
## dataset= Poll_Germ Data
seln.mod.PC1<-lmer(stdGerm~Elev*TRT*FlwPC1+Pop %in% Elev+(1|block))
anova(seln.mod.PC1)

seln.mod.PC2<-lmer(stdGerm~Elev*TRT*FlwPC2+Pop %in% Elev+(1|block))
anova(seln.mod.PC2)

seln.mod.all<-lmer(stdGerm~Elev*TRT*FlwPC1+FlwPC2+Pop %in% Elev+(1|block)+(1|Pop:geno2))
anova(mod1)



## Create correlation plots between flower PC1 and 49 flavonoid concentrations separately for low and high elevation clusters. 
## Dataset= Flav_andTrait_Data

loforcor<-read.table(pipe("pbpaste"),header=TRUE)
hiforcor<-read.table(pipe("pbpaste"),header=TRUE)
res.hi<-cor(hiforcor, use='complete.obs')
res.lo<-cor(loforcor, use='complete.obs')
res.hi2<-cor.mtest(hiforcor, use='complete.obs', conf.level=.999)
res.lo2<-cor.mtest(loforcor, use='complete.obs', conf.level=.999)
corrplot(res.lo, p.mat = res.lo2$p, method = "color", type = "upper",
       sig.level = c(.001), pch.cex = .9,
         insig = "label_sig", pch.col = "white")
corrplot(res.hi, p.mat = res.hi2$p, method = "color", type = "upper",
       sig.level = c(.001), pch.cex = .9,
        insig = "label_sig", pch.col = "white")

